/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import com.liferay.jenkins.results.parser.GitWorkingDirectory.Remote;

/**
 * @author Peter Yoo
 */
public class RemoteRepository extends BaseRepository {

	public String getHostname() {
		return hostname;
	}

	public String getRemoteURL() {
		return JenkinsResultsParserUtil.combine(
			"git@", hostname, ":", username, "/", name);
	}

	public String getUsername() {
		return username;
	}

	protected RemoteRepository(Remote remote) {
		this(
			remote.getHostname(), remote.getRepositoryName(),
			remote.getUsername());
	}

	protected RemoteRepository(
		String hostname, String repositoryName, String username) {

		super(repositoryName);

		if ((hostname == null) || hostname.isEmpty()) {
			throw new IllegalArgumentException("Hostname is null");
		}

		if ((username == null) || username.isEmpty()) {
			throw new IllegalArgumentException("Username is null");
		}

		this.hostname = hostname;
		this.username = username;
	}

	protected final String hostname;
	protected final String username;

}